WeightedMoments: Weighted Lmoment ratios (LCV and LSKEW) from a pooling group

View source: R/All.R

WeightedMomentsR Documentation

Weighted Lmoment ratios (LCV and LSKEW) from a pooling group

Description

Provides the weighted LCV and LSKEW for a pooling group

Usage

WeightedMoments(x)

Arguments

x

pooling group derived with the Pool() function

Details

Weighting method as according to: FEH2025

Value

A data.frame with site references in the first column and associated weights in the second

Author(s)

Anthony Hammond

Examples

# Get some CDs, form a gauged pooling group, and estimate gauged Lcv
cds_27051 <- GetCDs(27051)
pool_27051 <- Pool(cds_27051)
WeightedMoments(pool_27051)


UKFE documentation built on June 19, 2026, 5:08 p.m.