Extracts results from a data frame imported using the DDFImport function
Details
The .xml files only provide a set number of durations and return periods for DDF13 and DDF22. This is an interpolator function to derive depths for intervening durations and return periods. The result is rounded to an integer.
Examples
# Import DDF13 results from an NRFA Peak Flows XML file
if (FALSE) { # \dontrun{
ddf13_4003 <- DDFImport("C:/Data/NRFAPeakFlow_v9/Suitable for QMED/04003.xml", DDFVersion = 13)
} # }
# Estimate the 20-year, 5-hour depth
if (FALSE) { # \dontrun{
DDF(ddf13_4003, duration = 5, RP = 20)
} # }