Provides 11 plots to compare the sites in the pooling group
Arguments
- x
pooling group derived from the Pool() function
- gauged
logical argument with a default of FALSE. TRUE adds the top site in the pooling group to the plots in a different colour
- UrbMax
This is for the plotting of the URBEXT comparison. Ideally it should be the same as the UrbMax used for deriving the input pooling group
Examples
# Form a gauged pooling group and plot the diagnostics
pool_28015 <- Pool(GetCDs(28015))
DiagPlots(pool_28015, gauged = TRUE)
# Form an ungauged pooling group and plot the diagnostics
pool_28015 <- Pool(GetCDs(28015), exclude = 28015)
#> Warning: The exclude index did not match any gauges that are suitable for pooling and have URBEXT2015 below UrbMax
DiagPlots(pool_28015)